@@ -1,17 +1,13 @@
-package URI::Fast::IRI;
-$URI::Fast::IRI::VERSION = '0.23';
-our @ISA = qw(URI::Fast);
-1;
-
 package URI::Fast;
 # ABSTRACT: A fast(er) URI parser
-$URI::Fast::VERSION = '0.23';
+$URI::Fast::VERSION = '0.24';
 use strict;
 use warnings;
 no strict 'refs';
 
 use Carp;
 use Exporter;
+require URI::Fast::IRI;
 
 use Inline
   C        => 'DATA',
@@ -143,11 +139,11 @@ sub param {
 
 =head1 NAME
 
-URI::Fast::IRI - A fast(er) URI parser
+URI::Fast - A fast(er) URI parser
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
